@@ -1,18 +1,24 @@
 #!/usr/bin/env python3
 
-from seleniumwire import webdriver
+
+import logging
+from fake_headers import Headers
 # to add capabilities for chrome and firefox, import their Options with different aliases
 from selenium.webdriver.chrome.options import Options as CustomChromeOptions
+from selenium.webdriver.chrome.service import Service as ChromeService
 from selenium.webdriver.firefox.options import Options as CustomFireFoxOptions
+from selenium.webdriver.firefox.service import Service as FirefoxService
+from seleniumwire import webdriver
 # import webdriver for downloading respective driver for the browser
 from webdriver_manager.chrome import ChromeDriverManager
 from webdriver_manager.firefox import GeckoDriverManager
-from fake_headers import Headers
-from selenium.webdriver.chrome.service import Service as ChromeService
-from selenium.webdriver.firefox.service import Service as FirefoxService
-import logging
 
-logging.getLogger().setLevel(logging.INFO)
+logger = logging.getLogger(__name__)
+format = logging.Formatter(
+    "%(asctime)s - %(levelname)s - %(message)s")
+ch = logging.StreamHandler()
+ch.setFormatter(format)
+logger.addHandler(ch)
 
 
 class Initializer:
@@ -27,11 +33,14 @@ class Initializer:
         """adds capabilities to the driver"""
         header = Headers().generate()['User-Agent']
         if self.headless:
-            browser_option.add_argument(
-                '--headless')  # runs browser in headless mode
-        if self.profile and self.browser_name.lower() == 'chrome':
-            browser_option.add_argument(
-                'user-data-dir={}'.format(self.profile))
+            browser_option.add_argument("--headless")  # runs browser in headless mode
+        if self.profile and self.browser_name.lower() == "chrome":
+            browser_option.add_argument("user-data-dir={}".format(self.profile))
+        if self.profile and self.browser_name.lower() == "firefox":
+            logger.setLevel(logging.INFO)
+            logger.info("Loading Profile from {}".format(self.profile))
+            browser_option.add_argument("-profile")
+            browser_option.add_argument(self.profile)
         browser_option.add_argument('--no-sandbox')
         browser_option.add_argument("--disable-dev-shm-usage")
         browser_option.add_argument('--ignore-certificate-errors')
@@ -54,7 +63,8 @@ class Initializer:
                     'http': 'http://{}'.format(self.proxy.replace(" ", "")),
                     'no_proxy': 'localhost, 127.0.0.1'
                 }
-                logging.info("Using Proxy: {}".format(self.proxy))
+                logger.setLevel(logging.INFO)
+                logger.info("Using Proxy: {}".format(self.proxy))
 
                 return webdriver.Chrome(service=ChromeService(ChromeDriverManager().install()),
                                         options=self.set_properties(browser_option), seleniumwire_options=options)
@@ -62,17 +72,14 @@ class Initializer:
             return webdriver.Chrome(service=ChromeService(ChromeDriverManager().install()), options=self.set_properties(browser_option))
         elif browser_name.lower() == "firefox":
             browser_option = CustomFireFoxOptions()
-            if self.profile:
-                logging.info('Loading Profile from {}'.format(self.profile))
-                profile_path = webdriver.FirefoxProfile(self.profile)
-                browser_option.profile = profile_path
             if self.proxy is not None:
                 options = {
                     'https': 'https://{}'.format(self.proxy.replace(" ", "")),
                     'http': 'http://{}'.format(self.proxy.replace(" ", "")),
                     'no_proxy': 'localhost, 127.0.0.1'
                 }
-                logging.info("Using Proxy: {}".format(self.proxy))
+                logger.setLevel(logging.INFO)
+                logger.info("Using Proxy: {}".format(self.proxy))
                 return webdriver.Firefox(service=FirefoxService(executable_path=GeckoDriverManager().install()),
                                          options=self.set_properties(browser_option), seleniumwire_options=options)
 
